get_key_rotation_data

Function get_key_rotation_data 

pub(super) async fn get_key_rotation_data(
    api_client: &ApiClient,
) -> Result<KeyRotationData, SyncError>
Download the key rotation data from the server. This is the public keys for the password reset enrolled organizations and emergency-access grantees, and the encrypted keysets for the trusted devices and PRF-enabled passkeys. The server filters these to only the entries that participate in key rotation, so no client-side filtering is required.